/*
 * Copyright (C) 2014-2026 CZ.NIC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations including
 * the two.
 */

#include <QString>

#include "src/datovka_shared/utility/date_time.h"

const QString Utility::timeDisplayFormat("HH:mm:ss");

const QString Utility::dateTimeDisplayFormat("dd.MM.yyyy HH:mm:ss");
const QString Utility::dateTimeNoSecsDisplayFormat("dd.MM.yyyy HH:mm");

const QString Utility::dataTimeMSecsHyphenFormat("dd.MM.yyyy-HH:mm:ss.zzz");

const QString Utility::dateDisplayFormat("dd.MM.yyyy");
const QString Utility::dateMonthNameDisplayFormat("dd. MMMM yyyy");

const QString Utility::dateTimeFileSuffixFormat("yyyyMMdd-HHmmss-t");
